"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.memoize = exports.memoizeSupplier = void 0;
/**
 * Memoize the given supplier so that it is called at most once.
 */
const memoizeSupplier = (supplier) => {
    const name = supplier.name;
    let value;
    let done = false;
    return {
        [name]: () => {
            if (!done) {
                value = supplier();
                done = true;
            }
            return value;
        },
    }[name];
};
exports.memoizeSupplier = memoizeSupplier;
/**
 * Shorthand for {@link memoizeSupplier}.
 */
exports.memoize = exports.memoizeSupplier;
//# sourceMappingURL=memoize.js.map